﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.ComponentModel.DataAnnotations;

namespace MvcValidation.Models
{
    public class Zamowienie : IValidatableObject
    {
        [Required(ErrorMessage = "Pole jest wymagane")]
        [MinLength(6, ErrorMessage = "Numer musi mieć 6 znaków")]
        [MaxLength(6, ErrorMessage = "Numer musi mieć 6 znaków")]
        [RegularExpression("[A-Z]{3}[0-9]{3}", ErrorMessage = "Number musi mieć 3 litery i 3 cyfry")]
        public string Numer { get; set; }

        [Required(ErrorMessage = "Pole jest wymagane")]
        [MinLength(3, ErrorMessage = "Podaj odbiorcę")]
        public string Odbiorca { get; set; }

        [Required(ErrorMessage = "Pole jest wymagane")]
        [MinLength(3, ErrorMessage = "Podaj adres dostawy")]
        [Display(Name = "Adres dostawy")]
        public string AdresDostawy { get; set; }

        [Display(Name = "Data złożenia")]
        public DateTime DataZlozenia { get; set; }

        [Display(Name = "Data wysłania")]
        public DateTime DataWyslania { get; set; }

        [Display(Name = "Data dostarczenia")]
        public DateTime DataDostarczenia { get; set; }

        public IEnumerable<ValidationResult> Validate(ValidationContext validationContext)
        {
            if (DataZlozenia > DataWyslania)
                yield return new ValidationResult("Data złożenia nie może być późniejsza niż data wysłania.", new [] { "DataZlozenia" });
            if (DataWyslania > DataDostarczenia)
                yield return new ValidationResult("Data wysłania nie może być późniejsza niż data wysłania.", new[] { "DataWyslania" });
        }
    }
}